<?

class Mailing {
	
	private $id;
	private $title;
	private $text;
	private $lastSend;
	private $dateSend;
	private $type;
	private $executed;
	
	public function __construct($id = '', $title = '', $text = '', $lastSend = '', $dateSend= '', $type = '', $executed= '') {
		$this->SetId($id);
		$this->SetTitle($title);
		$this->SetText($text);
		$this->SetLastSend($lastSend);
		$this->SetDateSend($dateSend);
		$this->SetType($type);
		$this->SetExecuted($executed);		
	}
	
	public function SetId($id) {
		$this->id = $id;
	}
	public function SetTitle($title) {
		$this->title = stripslashes($title);
	}
	public function SetText($text) {
		$this->text = stripslashes($text);
	}
	public function SetLastSend($lastSend) {
		$this->lastSend = $lastSend;
	}
	public function SetDateSend($dateSend) {
		$this->dateSend = $dateSend;
	}
	public function SetType($type) {
		$this->type = $type;
	}
	public function SetExecuted($executed) {
		$this->executed = $executed;
	}
	
	public function GetId() {
		return $this->id;
	}
	public function GetTitle() {
		return $this->title;
	}
	public function GetText() {
		return $this->text;
	}
	public function GetTextClear() {
		return addslashes($this->text);
	}
	public function GetLastSend() {
		return $this->lastSend;
	}
	public function GetDateSend() {
		return $this->dateSend;
	}
	public function GetType() {
		return $this->type;
	}
	public function GetExecuted() {
		return $this->executed;
	}
	
	
	
}
?>